@@ -31,7 +31,14 @@ class TrelloConnection(object):
         params = params or {}
         params.update({'key': self.key, 'token': self.token})
         url += '?' + urlencode(params)
-        response = self.session.request(method, url, data=body)
+
+        # Trello recently got picky about headers.  Only set content type if
+        # we're submitting a payload in the body
+        if body:
+            headers = {'Content-Type': 'application/json'}
+        else:
+            headers = None
+        response = self.session.request(method, url, data=body, headers=headers)
         response.raise_for_status()
         return response.text
 
@@ -254,6 +261,22 @@ class LazyTrello(object):
             raise AttributeError("%r object has no attribute %r" %
                                  (type(self).__name__, attr))
 
+    def __unicode__(self):
+        tmpl = u'<%(cls)s: %(name_or_id)s>'
+        # If I have a name, use that
+        if 'name' in self._data:
+            return tmpl % {'cls': self.__class__.__name__,
+                           'name_or_id': self._data['name']}
+
+        return tmpl % {'cls': self.__class__.__name__,
+                       'name_or_id': self._id}
+
+    def __str__(self):
+        return str(self.__unicode__())
+
+    def __repr__(self):
+        return str(self.__unicode__())
+
 ### BEGIN ACTUAL WRAPPER OBJECTS
 
 
